@@ -71,7 +71,7 @@ class RosDebianGenerator(DebianGenerator):
         info("Releasing for rosdistro: " + self.rosdistro)
         return ret
 
-    def get_subs(self, package, debian_distro, releaser_history, native=False):
+    def get_subs(self, package, debian_distro, releaser_history, deb_inc=0, native=False):
         def fallback_resolver(key, peer_packages, rosdistro=self.rosdistro):
             if key in peer_packages:
                 return [sanitize_package_name(rosify_package_name(key, rosdistro))]
@@ -87,6 +87,7 @@ class RosDebianGenerator(DebianGenerator):
             releaser_history=releaser_history,
             fallback_resolver=fallback_resolver
         )
+        subs['Rosdistro'] = self.rosdistro
         subs['Package'] = rosify_package_name(subs['Package'], self.rosdistro)
 
         # ROS 2 specific bloom extensions.
@@ -107,14 +108,20 @@ class RosDebianGenerator(DebianGenerator):
                     self.rosdistro not in ('r2b2', 'r2b3', 'ardent') and \
                     'rosidl_interface_packages' in [p.name for p in package.member_of_groups]:
                 ROS2_VENDOR_TYPESUPPORT_DEPENDENCIES = [
-                    'rosidl-typesupport-connext-c',
-                    'rosidl-typesupport-connext-cpp',
                     'rosidl-typesupport-fastrtps-c',
                     'rosidl-typesupport-fastrtps-cpp',
                 ]
+
+                # Connext was changed to a new rmw that doesn't require typesupport after Foxy
+                if self.rosdistro in ('bouncy', 'crystal', 'dashing', 'eloquent', 'foxy'):
+                    ROS2_VENDOR_TYPESUPPORT_DEPENDENCIES.extend([
+                        'rosidl-typesupport-connext-c',
+                        'rosidl-typesupport-connext-cpp',
+                    ])
+
                 # OpenSplice was dropped after Eloquent.
                 # rmw implementations are required as dependencies up to Eloquent.
-                if self.rosdistro in ['bouncy', 'crystal', 'dashing', 'eloquent']:
+                if self.rosdistro in ('bouncy', 'crystal', 'dashing', 'eloquent'):
                     ROS2_VENDOR_TYPESUPPORT_DEPENDENCIES.extend([
                         'rmw-connext-cpp',
                         'rmw-fastrtps-cpp',
@@ -146,7 +153,7 @@ def rosify_package_name(name, rosdistro):
     return 'ros-{0}-{1}'.format(rosdistro, name)
 
 
-def get_subs(pkg, os_name, os_version, ros_distro, native):
+def get_subs(pkg, os_name, os_version, ros_distro, deb_inc, native):
     # No fallback_resolver provided because peer packages not considered.
     subs = generate_substitutions_from_package(
         pkg,
@@ -154,6 +161,7 @@ def get_subs(pkg, os_name, os_version, ros_distro, native):
         os_version,
         ros_distro,
         RosDebianGenerator.default_install_prefix + ros_distro,
+        deb_inc=deb_inc,
         native=native
     )
     subs['Package'] = rosify_package_name(subs['Package'], ros_distro)
